flutter_force_directed_graph
library
Typedefs
-
EdgeBuilder<T>
= Widget Function(BuildContext context, T a, T b, double distance)
-
A builder that builds an edge.
context is the build context.
a is the data of the node at the start of the edge.
b is the data of the node at the end of the edge.
distance is the distance between the two nodes.
-
NodeBuilder<T>
= Widget Function(BuildContext context, T data)
-
A builder that builds a node.
context is the build context.
data is the data of the node.
-
NodeDataDeserializer<T>
= T Function(dynamic data)
-
-
NodeDataSerializer<T>
= dynamic Function(T data)
-